Package: km.ci
Type: Package
Title: Confidence Intervals for the Kaplan-Meier Estimator
Version: 0.5-6
Date: 2022-04-04
Author: Ralf Strobl <rstrobl@ibe.med.uni-muenchen.de>
Maintainer: Tobias Verbeke <tobias.verbeke@openanalytics.eu>
Depends: R (>= 3.5.0)
Imports: stats, survival
Description: Computes various confidence intervals for the Kaplan-Meier
        estimator, namely: Peto's CI, Rothman CI, CI's based on
        Greenwood's variance, Thomas and Grunkemeier CI and the
        simultaneous confidence bands by Nair and Hall and Wellner.
License: GPL (>= 2)
Encoding: UTF-8
Repository: CRAN
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2022-04-05 08:49:03 UTC; tverbeke
Date/Publication: 2022-04-06 11:52:42 UTC
Built: R 4.6.0; ; 2026-04-26 03:23:53 UTC; unix
