# Generated by roxygen2: do not edit by hand

export(critical.value.hall.90)
export(critical.value.hall.95)
export(critical.value.hall.99)
export(critical.value.nair.90)
export(critical.value.nair.95)
export(km.ci)
import(survival)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(utils,data)
importFrom(utils,globalVariables)
